@@ -3,10 +3,7 @@ from __future__ import annotations
 import ast
 from typing import Optional
 
-import deal
 
-
-@deal.pure
 def extract_decorator_str_respresentation(
     decorator_node: ast.expr,
 ) -> Optional[str]:
